%define		major		2.2
%define		libname		%mklibname openimageio %{major}
%define		develname	%mklibname openimageio -d

%define		with_python3	1

# FIXME: Underlinking in Field3D
%define		_disable_ld_no_undefined	1

Name:		openimageio
Version:	2.2.10.0
Release:	%mkrel 1
Summary:	Library for reading and writing images
Group:		System/Libraries
License:	BSD
URL:		https://sites.google.com/site/openimageio/home
Source0:	https://github.com/OpenImageIO/oiio/archive/Release-%{version}/%{name}-%{version}.tar.gz
BuildRequires:	boost-devel
BuildRequires:	cmake
BuildRequires:	field3d-devel
BuildRequires:	giflib-devel
BuildRequires:	hdf5-devel
BuildRequires:	openvdb-devel
BuildRequires:	squish-devel
BuildRequires:	cmake(DCMTK)
BuildRequires:	cmake(fmt)
BuildRequires:	pkgconfig(IlmBase)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(OpenEXR)
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(jasper)
BuildRequires:	pkgconfig(libavcodec)
BuildRequires:	pkgconfig(libavformat)
BuildRequires:	pkgconfig(libavutil)
BuildRequires:	pkgconfig(libheif)
BuildRequires:	pkgconfig(libopenjp2)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libraw)
BuildRequires:	pkgconfig(libraw_r)
BuildRequires:	pkgconfig(libswscale)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(libwebp)
BuildRequires:	pkgconfig(OpenColorIO)
BuildRequires:	pkgconfig(opencv)
BuildRequires:	pkgconfig(openssl)
%if %{with_python3}
BuildRequires:	pkgconfig(python3)
%endif
BuildRequires:	pkgconfig(tbb)
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Network)
BuildRequires:	pkgconfig(Qt5OpenGL)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(pugixml)
BuildRequires:	txt2man
# New build requirements for 2.0
BuildRequires:	cmake(tsl-robin-map)
BuildRequires:	pybind11-devel

Obsoletes:	OpenImageIO < %{version}

%description
OpenImageIO is a library for reading and writing images, and a bunch of related
classes, utilities, and applications. Main features include:
- Extremely simple but powerful ImageInput and ImageOutput APIs for reading and
  writing 2D images that is format agnostic.
- Format plugins for TIFF, JPEG/JFIF, OpenEXR, PNG, HDR/RGBE, Targa, JPEG-2000,
  DPX, Cineon, FITS, BMP, ICO, RMan Zfile, Softimage PIC, DDS, SGI,
  PNM/PPM/PGM/PBM, Field3d.
- An ImageCache class that transparently manages a cache so that it can access
  truly vast amounts of image data.
- A really nice image viewer, iv, also based on OpenImageIO classes (and so
  will work with any formats for which plugins are available).

%package -n %{libname}
Summary:	A library for reading and writing images
Group:		System/Libraries

%description -n %{libname}
OpenImageIO is a library for reading and writing images.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{develname}
Development files for %{name} library.

%if %{with_python3}
%package -n python3-%{name}
Summary:	Python 3 bindings for %{name}
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python3-OpenImageIO = %{version}-%{release}

Obsoletes:	python2-openimageio < 1.8.17-4

%description -n python3-%{name}
Python3 bindings for %{name}.
%endif

%prep
%setup -qn oiio-Release-%{version}
%autopatch -p1

# Remove bundled pugixml
rm -f src/include/OpenImageIO/pugixml.hpp \
      src/include/OpenImageIO/pugiconfig.hpp \
      src/include/OpenImageIO/pugixml.cpp

# Remove bundled tbb
rm -rf src/include/tbb

%build
%cmake \
       -DPYTHON_VERSION=%{python3_version} \
       -DUSE_PYTHON:BOOL=ON \
       -DSTOP_ON_WARNING=OFF \
       -DUSE_EXTERNAL_PUGIXML:BOOL=ON \
       -DOpenGL_GL_PREFERENCE=GLVND \
       -DVERBOSE=TRUE
%cmake_build

%install
%cmake_install

# Move man pages to the right directory
mkdir -p %{buildroot}%{_mandir}/man1
mv %{buildroot}%{_mandir}/*.1 %{buildroot}%{_mandir}/man1

rm -fr %{buildroot}%{_docdir}

%files
%license LICENSE.md
%{_bindir}/*
%{_xfontdir}/OpenImageIO
%{_mandir}/man1/*

%files -n %{libname}
%license LICENSE.md
%{_libdir}/libOpenImageIO.so.%{major}{,.*}
%{_libdir}/libOpenImageIO_Util.so.%{major}{,.*}

%files -n %{develname}
%doc CHANGES.md
%doc README.md
%license LICENSE.md
%{_libdir}/libOpenImageIO.so
%{_libdir}/libOpenImageIO_Util.so
%dir %{_includedir}/OpenImageIO
%{_includedir}/OpenImageIO/*
%{_libdir}/pkgconfig/OpenImageIO.pc
%{_libdir}/cmake/OpenImageIO/
%{_datadir}/cmake/Modules/FindOpenImageIO.cmake

%if %{with_python3}
%files -n python3-%{name}
%{python3_sitearch}/OpenImageIO.so
%endif


%changelog
* Mon Jan 04 2021 daviddavid <daviddavid> 2.2.10.0-1.mga8
+ Revision: 1668585
- new version: 2.2.10.0

* Thu Dec 31 2020 wally <wally> 2.2.9.0-5.mga8
+ Revision: 1666794
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2.2.9.0-4.mga8
+ Revision: 1662036
- rebuild for boost 1.74.0

* Thu Dec 17 2020 luigiwalser <luigiwalser> 2.2.9.0-3.mga8
+ Revision: 1660527
- rebuild for missing signature

* Thu Dec 17 2020 umeabot <umeabot> 2.2.9.0-2.mga8
+ Revision: 1659213
- Rebuild for new Qt5

* Fri Dec 04 2020 daviddavid <daviddavid> 2.2.9.0-1.mga8
+ Revision: 1652436
- new version: 2.2.9.0

* Tue Nov 03 2020 akien <akien> 2.2.8.0-1.mga8
+ Revision: 1642035
- Version 2.2.8.0
- Rebuild against opencv 4.5
+ daviddavid <daviddavid>
- new version: 2.2.7.0 (mga#27490)
- now libmajor is 2.2

* Sat Sep 12 2020 daviddavid <daviddavid> 2.1.19.0-2.mga8
+ Revision: 1625009
- rebuild for new openexr 2.5.3 and new hdf5 1.10.6

* Wed Sep 02 2020 daviddavid <daviddavid> 2.1.19.0-1.mga8
+ Revision: 1620758
- new version: 2.1.19.0

* Tue Aug 18 2020 daviddavid <daviddavid> 2.1.18.1-2.mga8
+ Revision: 1614926
- rebuild for new openvdb 7.1.0

* Sun Aug 02 2020 daviddavid <daviddavid> 2.1.18.1-1.mga8
+ Revision: 1610480
- new version: 2.1.18.1

* Sat Aug 01 2020 daviddavid <daviddavid> 2.1.18.0-1.mga8
+ Revision: 1610200
- new version: 2.1.18.0

* Thu Jul 02 2020 daviddavid <daviddavid> 2.1.17.0-1.mga8
+ Revision: 1601390
- new version: 2.1.17.0
- remove merged upstream patch

* Sat Jun 20 2020 daviddavid <daviddavid> 2.1.16.0-2.mga8
+ Revision: 1597542
- add upstream patch to fix Qt 5.15 support

* Tue Jun 02 2020 daviddavid <daviddavid> 2.1.16.0-1.mga8
+ Revision: 1589620
- new version: 2.1.16.0

* Mon May 11 2020 daviddavid <daviddavid> 2.1.15.0-1.mga8
+ Revision: 1583216
- new version: 2.1.15.0

* Sun May 03 2020 wally <wally> 2.1.14.0-2.mga8
+ Revision: 1578090
- rebuild for boost 1.73.0

* Sat May 02 2020 daviddavid <daviddavid> 2.1.14.0-1.mga8
+ Revision: 1577773
- new version: 2.1.14.0
- remove merged upstream patch

* Sat Apr 04 2020 daviddavid <daviddavid> 2.1.13.0-2.mga8
+ Revision: 1564544
- rebuild for new fmt 6.1.2

* Fri Apr 03 2020 daviddavid <daviddavid> 2.1.13.0-1.mga8
+ Revision: 1564135
- new version: 2.1.13.0
- now libmajor is 2.1
- enable field3d and squish support
- enable libheif and fmt support
- enable openvdb support

* Wed Feb 19 2020 umeabot <umeabot> 2.0.13-3.mga8
+ Revision: 1544853
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 wally <wally> 2.0.13-2.mga8
+ Revision: 1483408
- rebuild for boost 1.72.0
- build with new cmake macros

* Wed Dec 04 2019 daviddavid <daviddavid> 2.0.13-1.mga8
+ Revision: 1464195
- new version: 2.0.13

* Tue Nov 05 2019 daviddavid <daviddavid> 2.0.12-1.mga8
+ Revision: 1457783
- new version: 2.0.12

* Thu Oct 31 2019 daviddavid <daviddavid> 2.0.11-3.mga8
+ Revision: 1457113
- rebuild for new dcmtk 3.6.5

* Mon Oct 07 2019 tv <tv> 2.0.11-2.mga8
+ Revision: 1450212
- rebuild with python 3.8

* Wed Oct 02 2019 daviddavid <daviddavid> 2.0.11-1.mga8
+ Revision: 1448720
- new version: 2.0.11

* Tue Sep 17 2019 daviddavid <daviddavid> 2.0.9-2.mga8
+ Revision: 1442778
- rebuild for python3.8

* Mon Jul 15 2019 daviddavid <daviddavid> 2.0.9-1.mga8
+ Revision: 1421558
- new version: 2.0.9
- now libmajor is 2.0
- switch to Python3 and drop Python2 support

* Sun Mar 31 2019 umeabot <umeabot> 1.8.17-3.mga7
+ Revision: 1383624
- Qt5 Rebuild

* Sun Jan 06 2019 daviddavid <daviddavid> 1.8.17-2.mga7
+ Revision: 1350093
- rebuild for new dcmtk 3.6.4

* Sun Dec 02 2018 daviddavid <daviddavid> 1.8.17-1.mga7
+ Revision: 1337383
- new version: 1.8.17

* Fri Nov 02 2018 daviddavid <daviddavid> 1.8.16-1.mga7
+ Revision: 1327565
- new version: 1.8.16

* Tue Oct 16 2018 wally <wally> 1.8.15-3.mga7
+ Revision: 1321071
- rebuild for new boost 1.68.0

* Mon Oct 15 2018 daviddavid <daviddavid> 1.8.15-2.mga7
+ Revision: 1320480
- rebuild for new ilmbase and openexr 2.3.0

* Tue Oct 02 2018 daviddavid <daviddavid> 1.8.15-1.mga7
+ Revision: 1315827
- new version: 1.8.15

* Mon Sep 03 2018 daviddavid <daviddavid> 1.8.14-1.mga7
+ Revision: 1256742
- new version: 1.8.14
- remove merged upstream patch

* Sun May 27 2018 wally <wally> 1.8.10-3.mga7
+ Revision: 1232427
- rebuild for openexr 2.2.1

* Tue May 01 2018 daviddavid <daviddavid> 1.8.10-2.mga7
+ Revision: 1224138
- enable DCMTK support

* Tue May 01 2018 daviddavid <daviddavid> 1.8.10-1.mga7
+ Revision: 1224102
- new version: 1.8.10
- switch to openjpeg2
- rename and rediff dl patch

* Tue May 01 2018 daviddavid <daviddavid> 1.8.6-5.mga7
+ Revision: 1224093
- add upstream patch to fix build with ffmpeg 4.0
- rename python-openimageio to python2-openimageio
- split out all Qt5 BRs

* Sat Jan 13 2018 wally <wally> 1.8.6-4.mga7
+ Revision: 1192567
- rebuild for new ilmbase

* Mon Dec 25 2017 wally <wally> 1.8.6-3.mga7
+ Revision: 1184694
- rebuild for new boost

* Sun Dec 03 2017 daviddavid <daviddavid> 1.8.6-2.mga7
+ Revision: 1180819
- rebuild for new glew 2.1.0

* Wed Nov 22 2017 tv <tv> 1.8.6-1.mga7
+ Revision: 1178682
- new major
- rediff patch 0
- remove no more needed patch 1
- fix man pages path
- fix filelist
- py3 build seems failing
- new release

* Tue Nov 21 2017 tv <tv> 1.7.17-1.mga7
+ Revision: 1178460
- new release
- rebuild for boost 1.65

* Sat Sep 16 2017 tv <tv> 1.7.14-3.mga7
+ Revision: 1154575
- rebuild with latest boost

* Sat Aug 05 2017 pterjan <pterjan> 1.7.14-2.mga7
+ Revision: 1135282
- Rebuild for python 3.6

* Tue May 16 2017 luigiwalser <luigiwalser> 1.7.14-1.mga6
+ Revision: 1102070
- 1.7.14
- add patch from fedora to fix arch/optimizer specific problem with
  uninitialized variables

* Tue May 02 2017 akien <akien> 1.7.9-3.mga6
+ Revision: 1098369
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 1.7.9-2.mga6
+ Revision: 1090229
- Rebuild for ffmpeg 3.2.4

* Wed Dec 28 2016 wally <wally> 1.7.9-1.mga6
+ Revision: 1078446
- new version 1.7.9
- fix pkg names (use lower case)
- rediff linking patch

* Tue Dec 27 2016 neoclust <neoclust> 1.6.17-2.mga6
+ Revision: 1078383
- Rebuild against new libraw

* Sat Oct 01 2016 daviddavid <daviddavid> 1.6.17-1.mga6
+ Revision: 1057976
- new version: 1.6.17

* Sat Apr 09 2016 daviddavid <daviddavid> 1.6.12-1.mga6
+ Revision: 999805
- new version: 1.6.12

* Sun Jan 10 2016 daviddavid <daviddavid> 1.6.9-2.mga6
+ Revision: 920961
- rebuild for new giflib 5.1.2

* Wed Jan 06 2016 daviddavid <daviddavid> 1.6.9-1.mga6
+ Revision: 920121
- new version: 1.6.9
- now libmajor is 1.6
- update file list

* Tue Jan 05 2016 daviddavid <daviddavid> 1.5.23-1.mga6
+ Revision: 919818
- new version: 1.5.23
- reenable python binding build (upstream fixed build with boost 1.60.0)
- move python bindings to their own subpackage
- add python 3 subpackage

* Sat Jan 02 2016 luigiwalser <luigiwalser> 1.5.22-2.mga6
+ Revision: 918204
- rebuild for libwebp

* Sun Dec 27 2015 daviddavid <daviddavid> 1.5.22-1.mga6
+ Revision: 916060
- new version: 1.5.22
- rebuild for new libraw 0.17.1

* Sat Dec 26 2015 daviddavid <daviddavid> 1.5.18-3.mga6
+ Revision: 915100
- temporarily disable python binding build (uncompatible with boost 1.60.0 for now)
- rebuild for new boost 1.60.0

* Fri Sep 25 2015 daviddavid <daviddavid> 1.5.18-2.mga6
+ Revision: 883479
- rebuild for new boost 1.59.0

* Wed Aug 26 2015 fwang <fwang> 1.5.18-1.mga6
+ Revision: 869481
- install man pages
- br opencolorio
- disable doc install
- update file list
- use openssl
- add more br
- 1.5.18

* Mon Aug 24 2015 daviddavid <daviddavid> 1.2.0-15.mga6
+ Revision: 868898
- rebuild for new glew 1.13.0

* Fri Jul 31 2015 fwang <fwang> 1.2.0-14.mga6
+ Revision: 859426
- rebuild for new boost

* Tue Jun 23 2015 fwang <fwang> 1.2.0-13.mga6
+ Revision: 840506
- rebuild for new glew

* Wed Oct 15 2014 umeabot <umeabot> 1.2.0-12.mga5
+ Revision: 750496
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.2.0-11.mga5
+ Revision: 683214
- Mageia 5 Mass Rebuild

* Fri Sep 05 2014 luigiwalser <luigiwalser> 1.2.0-10.mga5
+ Revision: 672251
- rebuild for glew

* Sun Aug 24 2014 luigiwalser <luigiwalser> 1.2.0-9.mga5
+ Revision: 666999
- rebuild for ilmbase and OpenEXR

* Thu Aug 07 2014 fwang <fwang> 1.2.0-8.mga5
+ Revision: 660835
- rebuild for new pugixml

* Fri Apr 25 2014 akien <akien> 1.2.0-7.mga5
+ Revision: 618074
- Rebuild for new OpenEXR and IlmBase

* Sat Feb 15 2014 luigiwalser <luigiwalser> 1.2.0-6.mga5
+ Revision: 592108
- rebuild for libwebp

* Sat Feb 08 2014 barjac <barjac> 1.2.0-5.mga5
+ Revision: 586737
- rebuild against boost-1.55

* Sat Oct 19 2013 umeabot <umeabot> 1.2.0-4.mga4
+ Revision: 534418
- Mageia 4 Mass Rebuild

* Thu Sep 12 2013 fwang <fwang> 1.2.0-3.mga4
+ Revision: 477848
- rebuild for new openexr

* Wed Jul 24 2013 sander85 <sander85> 1.2.0-2.mga4
+ Revision: 457678
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 1.2.0-1.mga4
+ Revision: 454647
- disable werror
- update dl patch
- new version 1.2.0

* Mon Jul 08 2013 fwang <fwang> 1.0.8-11.mga4
+ Revision: 451208
- rebuild for new boost

* Thu Jun 06 2013 fwang <fwang> 1.0.8-10.mga4
+ Revision: 438301
- rebuild again for updated openjpeg

* Thu Jun 06 2013 fwang <fwang> 1.0.8-9.mga4
+ Revision: 438284
- rebuild for new openjpeg

* Sun Jun 02 2013 fwang <fwang> 1.0.8-8.mga4
+ Revision: 434729
- rebuild for new libpng

* Thu Apr 11 2013 barjac <barjac> 1.0.8-7.mga3
+ Revision: 409667
- rebuild for boost-1.53

* Sun Jan 13 2013 umeabot <umeabot> 1.0.8-6.mga3
+ Revision: 362041
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 1.0.8-5.mga3
+ Revision: 332957
- rebuild for new boost

* Sun Dec 02 2012 fwang <fwang> 1.0.8-4.mga3
+ Revision: 325021
- rebuild for  new openexr

* Sun Oct 07 2012 fwang <fwang> 1.0.8-3.mga3
+ Revision: 303247
- rebuild for new openjpeg

* Tue Aug 21 2012 fwang <fwang> 1.0.8-2.mga3
+ Revision: 282870
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 1.0.8-1.mga3
+ Revision: 276474
- new version 1.0.8
- rebuild for new glew

* Tue May 29 2012 fwang <fwang> 1.0.4-2.mga3
+ Revision: 249531
- rebuild for new boost

* Fri May 25 2012 fwang <fwang> 1.0.4-1.mga3
+ Revision: 236018
- fix upgrade from previous name
- br jpeg
- imported package openimageio

